@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2020 Richard Hughes <richard@hughsie.com>
+ * Copyright 2020 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #define G_LOG_DOMAIN "XbCommon"
@@ -31,7 +31,7 @@ xb_content_type_guess_from_fn(const gchar *filename)
 		return "application/x-xz";
 	if (g_strcmp0(ext, ".zst") == 0)
 		return "application/zstd";
-	if (g_strcmp0(ext, ".txt") == 0 || g_strcmp0(ext, ".xml") == 0)
+	if (g_strcmp0(ext, ".xml") == 0)
 		return "application/xml";
 	if (g_strcmp0(ext, ".desktop") == 0)
 		return "application/x-desktop";
@@ -116,8 +116,7 @@ xb_content_type_guess(const gchar *filename, const guchar *buf, gsize bufsz)
  * @cancellable: (nullable): optional #GCancellable
  * @error: (nullable): optional return location for an error
  *
- * Writes data to a file. This is done safely using a temporary file to do this
- * atomically on Linux but a direct write is used on Windows.
+ * Writes data to a file.
  *
  * Returns: %TRUE for success
  **/
@@ -128,32 +127,10 @@ xb_file_set_contents(GFile *file,
 		     GCancellable *cancellable,
 		     GError **error)
 {
-#ifdef _WIN32
-	g_autofree gchar *fn = g_file_get_path(file);
-#endif
-
 	g_return_val_if_fail(G_IS_FILE(file), FALSE);
 	g_return_val_if_fail(buf != NULL, FALSE);
 	g_return_val_if_fail(cancellable == NULL || G_IS_CANCELLABLE(cancellable), FALSE);
 	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
-
-#ifdef _WIN32
-#if GLIB_CHECK_VERSION(2, 66, 0)
-	return g_file_set_contents_full(fn,
-					(const gchar *)buf,
-					(gssize)bufsz,
-					G_FILE_SET_CONTENTS_NONE,
-					0666,
-					error);
-
-#else
-	g_set_error_literal(error,
-			    G_IO_ERROR,
-			    G_IO_ERROR_NOT_SUPPORTED,
-			    "not supported as GLib version is too old");
-	return FALSE;
-#endif
-#else
 	return g_file_replace_contents(file,
 				       (const gchar *)buf,
 				       (gsize)bufsz,
@@ -163,5 +140,4 @@ xb_file_set_contents(GFile *file,
 				       NULL,
 				       cancellable,
 				       error);
-#endif
 }
