@@ -66,13 +66,21 @@ xb_silo_export_node(XbSilo *self, XbSiloExportHelper *helper, XbSiloNode *sn, GE
 	    xb_silo_node_get_text_idx(sn) == XB_SILO_UNSET &&
 	    xb_silo_get_child_node(self, sn, NULL) == NULL) {
 		g_string_append(helper->xml, " />");
+
+		/* offset by opening tag and single byte sentinel */
+		helper->off += xb_silo_node_get_size(sn);
+		sn2 = xb_silo_get_node(self, helper->off, error);
+		if (sn2 == NULL)
+			return FALSE;
+		helper->off += xb_silo_node_get_size(sn2);
 	} else {
 		/* finish the opening tag and add any text if it exists */
 		if (xb_silo_node_get_text_idx(sn) != XB_SILO_UNSET) {
 			const gchar *text_unsafe;
 			g_autofree gchar *text = NULL;
 
-			text_unsafe = xb_silo_get_node_text(self, sn, error);
+			text_unsafe =
+			    xb_silo_from_strtab(self, xb_silo_node_get_text_idx(sn), error);
 			if (text_unsafe == NULL)
 				return FALSE;
 			text = xb_string_xml_escape(text_unsafe);
@@ -126,7 +134,7 @@ xb_silo_export_node(XbSilo *self, XbSiloExportHelper *helper, XbSiloNode *sn, GE
 		const gchar *tail_unsafe;
 		g_autofree gchar *tail = NULL;
 
-		tail_unsafe = xb_silo_get_node_tail(self, sn, error);
+		tail_unsafe = xb_silo_from_strtab(self, xb_silo_node_get_tail_idx(sn), error);
 		if (tail_unsafe == NULL)
 			return FALSE;
 		tail = xb_string_xml_escape(tail_unsafe);
