@@ -178,7 +178,7 @@ const gchar *
 xb_silo_from_strtab(XbSilo *self, guint32 offset, GError **error)
 {
 	XbSiloPrivate *priv = GET_PRIVATE(self);
-	if (offset == XB_SILO_UNSET) {
+	if (G_UNLIKELY(offset == XB_SILO_UNSET)) {
 		g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND, "offset was unset");
 		return NULL;
 	}
@@ -258,11 +258,11 @@ XbSiloNode *
 xb_silo_get_root_node(XbSilo *self, GError **error)
 {
 	XbSiloPrivate *priv = GET_PRIVATE(self);
-	if (priv->blob == NULL) {
+	if (G_UNLIKELY(priv->blob == NULL)) {
 		g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_INVALID_DATA, "no blob loaded");
 		return NULL;
 	}
-	if (g_bytes_get_size(priv->blob) < sizeof(XbSiloHeader)) {
+	if (G_UNLIKELY(g_bytes_get_size(priv->blob) < sizeof(XbSiloHeader))) {
 		g_set_error(error,
 			    G_IO_ERROR,
 			    G_IO_ERROR_INVALID_DATA,
@@ -270,7 +270,7 @@ xb_silo_get_root_node(XbSilo *self, GError **error)
 			    (guint)g_bytes_get_size(priv->blob));
 		return NULL;
 	}
-	if (g_bytes_get_size(priv->blob) == sizeof(XbSiloHeader)) {
+	if (G_UNLIKELY(g_bytes_get_size(priv->blob) == sizeof(XbSiloHeader))) {
 		g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND, "no node data");
 		return NULL;
 	}
@@ -281,7 +281,7 @@ xb_silo_get_root_node(XbSilo *self, GError **error)
 XbSiloNode *
 xb_silo_get_parent_node(XbSilo *self, XbSiloNode *n, GError **error)
 {
-	if (n->parent == 0x0) {
+	if (G_UNLIKELY(n->parent == 0x0)) {
 		g_set_error(error,
 			    G_IO_ERROR,
 			    G_IO_ERROR_INVALID_ARGUMENT,
@@ -395,6 +395,7 @@ xb_silo_to_string(XbSilo *self, GError **error)
 
 	g_string_append_printf(str, "magic:        %08x\n", (guint)hdr->magic);
 	g_string_append_printf(str, "guid:         %s\n", priv->guid);
+	g_string_append_printf(str, "filesz:       @%" G_GUINT64_FORMAT "\n", hdr->filesz);
 	g_string_append_printf(str, "strtab:       @%" G_GUINT32_FORMAT "\n", hdr->strtab);
 	g_string_append_printf(str, "strtab_ntags: %" G_GUINT16_FORMAT "\n", hdr->strtab_ntags);
 	while (off < priv->strtab) {
@@ -488,26 +489,6 @@ xb_silo_to_string(XbSilo *self, GError **error)
 	return g_string_free(g_steal_pointer(&str), FALSE);
 }
 
-/* private */
-const gchar *
-xb_silo_get_node_text(XbSilo *self, XbSiloNode *n, GError **error)
-{
-	guint32 idx = xb_silo_node_get_text_idx(n);
-	if (idx == XB_SILO_UNSET)
-		return NULL;
-	return xb_silo_from_strtab(self, idx, error);
-}
-
-/* private */
-const gchar *
-xb_silo_get_node_tail(XbSilo *self, XbSiloNode *n, GError **error)
-{
-	guint idx = xb_silo_node_get_tail_idx(n);
-	if (idx == XB_SILO_UNSET)
-		return NULL;
-	return xb_silo_from_strtab(self, idx, error);
-}
-
 /* private */
 const gchar *
 xb_silo_get_node_element(XbSilo *self, XbSiloNode *n, GError **error)
@@ -819,6 +800,12 @@ xb_silo_load_from_bytes(XbSilo *self, GBytes *blob, XbSiloLoadFlags flags, GErro
 		}
 	}
 
+	/* check size */
+	if (hdr->filesz != sz) {
+		g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_INVALID_DATA, "filesz incorrect");
+		return FALSE;
+	}
+
 	/* get GUID */
 	memcpy(&guid_tmp, &hdr->guid, sizeof(guid_tmp));
 	priv->guid = xb_guid_to_string(&guid_tmp);
@@ -829,6 +816,13 @@ xb_silo_load_from_bytes(XbSilo *self, GBytes *blob, XbSiloLoadFlags flags, GErro
 		g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_INVALID_DATA, "strtab incorrect");
 		return FALSE;
 	}
+	if (hdr->strtab_ntags > 0 && priv->data[sz - 1] != '\0') {
+		g_set_error_literal(error,
+				    G_IO_ERROR,
+				    G_IO_ERROR_INVALID_DATA,
+				    "strtab invalid, trailing NUL not found");
+		return FALSE;
+	}
 
 	/* load strtab_tags */
 	for (guint16 i = 0; i < hdr->strtab_ntags; i++) {
@@ -1440,11 +1434,15 @@ xb_silo_machine_func_text_cb(XbMachine *self,
 		return FALSE;
 	}
 
+	if (xb_silo_node_get_text_idx(query_data->sn) != XB_SILO_UNSET) {
+		text = xb_silo_from_strtab(silo, xb_silo_node_get_text_idx(query_data->sn), error);
+		if (text == NULL)
+			return FALSE;
+	} else {
+		text = "";
+	}
 	if (!xb_machine_stack_push(self, stack, &op, error))
 		return FALSE;
-	text = xb_silo_get_node_text(silo, query_data->sn, error);
-	if (text == NULL)
-		return FALSE;
 	xb_opcode_init(op,
 		       XB_OPCODE_KIND_INDEXED_TEXT,
 		       text,
@@ -1490,11 +1488,15 @@ xb_silo_machine_func_tail_cb(XbMachine *self,
 		return FALSE;
 	}
 
+	if (xb_silo_node_get_tail_idx(query_data->sn) != XB_SILO_UNSET) {
+		tail = xb_silo_from_strtab(silo, xb_silo_node_get_tail_idx(query_data->sn), error);
+		if (tail == NULL)
+			return FALSE;
+	} else {
+		tail = "";
+	}
 	if (!xb_machine_stack_push(self, stack, &op, error))
 		return FALSE;
-	tail = xb_silo_get_node_tail(silo, query_data->sn, error);
-	if (tail == NULL)
-		return FALSE;
 	xb_opcode_init(op,
 		       XB_OPCODE_KIND_INDEXED_TEXT,
 		       tail,
